//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[TileType](index.md)/[entries](entries.md)

# entries

[common]\
val [entries](entries.md): [EnumEntries](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.enums/-enum-entries/index.html)&lt;[TileType](index.md)&gt;

Returns a representation of an immutable list of all enum entries, in the order they're declared.

This method may be used to iterate over the enum entries.
